
from django.contrib.auth.models import User
from django.db import models
from django.urls import reverse
from ckeditor_uploader.fields import RichTextUploadingField 
from bigsansar.contrib.sites.models import domains
import time


def user_directory_path(instance, filename):

    # file will be uploaded to MEDIA_ROOT / username/<y>/ <m> / <d> / <filename> >
    years = time.strftime("%Y")
    month = time.strftime("%m")
    day = time.strftime("%d")
    get_time = years + '/' + month + '/' + day

    return str("%s/%s/%s" % (instance.user.username, get_time, filename))
  
# Create your models here.

class post(models.Model):
    domain = models.ForeignKey(domains, on_delete=models.CASCADE)
    user = models.ForeignKey(User, on_delete=models.CASCADE)
    title = models.CharField(max_length=100, default='| Bigsansar')
    slug = models.SlugField(unique=True)
    thumbnails = models.ImageField(upload_to=user_directory_path, blank=True)
    body = RichTextUploadingField()
    publish_date = models.DateField(auto_now_add=True)

    def delete(self, using=None, keep_parents=False):
        try:

            self.thumbnails.storage.delete(self.thumbnails.name)
        except:
            pass
        
        super().delete()

    def __str__(self):
        return self.title
    
    def get_absolute_url(self):
        return "http://%s/blog/preview/%s" % (self.domain, self.id)

    class Meta:
        verbose_name = 'Posts'
        verbose_name_plural = 'Posts'

    # def get_absolute_url(self):
    #     return reverse("blog", kwargs={"slug": self.slug})


class comment(models.Model):
    user = models.ForeignKey(User, on_delete=models.CASCADE)
    title = models.ForeignKey(post, on_delete=models.CASCADE)
    comments = models.TextField()
    reply = models.ForeignKey('self', on_delete=models.CASCADE, null=True)
    publish_date = models.DateTimeField(auto_now=True)

    def __str__(self):
        return self.comments

    class Meta:
        verbose_name = 'Comments'
        verbose_name_plural = 'Comments'



import datetime
import os
from bigsansar.contrib.advance.models import css, javascript
from www.settings import BASE_DIR
from django.contrib.sites.shortcuts import get_current_site
from django.http import HttpResponse
from django.shortcuts import render
from django.template import loader
from bigsansar.contrib.blogs.models import post
from bigsansar.contrib.sites.models import domains, pages

DEFAULT_TEMPLATE = 'default.html'


def index(request):
    try:
        current_site = get_current_site(request)
        db = domains.objects.get(domain=current_site)
        total = db.visitor + 1
        domains.objects.filter(pk=db.id).update(visitor=total)


    except:
        current_site = get_current_site(request)
        time = datetime.datetime.now()
        return render(request, 'parking.html', {'domain': current_site, 'time': time})

    else:
        asp = 'templates/' + str(db.domain) + '/' + 'index.html'
        full_url = os.path.join(BASE_DIR, asp)
        template = loader.select_template((full_url, DEFAULT_TEMPLATE))
            
        return HttpResponse(template.render({'gethost': db}, request))


def pathviews(request, url):
    default_page = 'defaultpage.html'

    try:
        current_site = get_current_site(request)
        db = domains.objects.get(domain=current_site)
        get_pagename = url.strip('/')
        page = pages.objects.get(domain=db, slug=get_pagename)
        total = db.visitor + 1
        pagetotal = page.visitor + 1
        domains.objects.filter(pk=db.id).update(visitor=total)
        pages.objects.filter(domain=db, slug=get_pagename).update(visitor=pagetotal)

    except:

        return render(request, '404.html')

    else:
        asp = 'templates/' + str(db.domain) + '/' + page.slug + '.html'
        full_url = os.path.join(BASE_DIR, asp)
        template = loader.select_template((full_url, default_page))
        return HttpResponse(template.render({'gethost': db, 'getpage': page}, request))



def get_path_url(request, path, slug):
    default_page = 'defaultpage.html'
    try:
        current_site = get_current_site(request)
        db = domains.objects.get(domain=current_site)
        get_pagename = path.strip('/')
        page = pages.objects.get(domain=db, slug=get_pagename)
        total = db.visitor + 1
        domains.objects.filter(pk=db.id).update(visitor=total)
        

    except:
        return render(request, '404.html')
    
    else:
         
         asp = 'templates/' + str(db.domain) + '/' + page.slug + '.html'
         full_url = os.path.join(BASE_DIR, asp)
         template = loader.select_template((full_url, default_page))
         return HttpResponse(template.render({'gethost': db, 'getpage': page, 'slug': slug}, request))

def getcss(request):
    try:
        current_site = get_current_site(request)
        db = domains.objects.get(domain=current_site)
        get_css = css.objects.get(domain = db)
    except:

        return render(request, '404.html')
    
    else:

        gethttp = HttpResponse(get_css.css)
        gethttp['Content-Type'] = 'text/css'
        return gethttp
    

def getjavascript(request):
    try:
        current_site = get_current_site(request)
        db = domains.objects.get(domain=current_site)
        get_javascript = javascript.objects.get(domain = db)
    except:
        return render(request, '404.html')
    
    else:

        getjavahttp = HttpResponse(get_javascript.javascript)
        getjavahttp['Content-Type'] = 'text/javascript'
        return getjavahttp
    

def sitemap(request):
    try:
        current_site = get_current_site(request)
        domains.objects.get(domain=current_site)
    except:
        return render(request, '404.html')
    
    else:
        template = loader.get_template('sitemap.html')
        getsitemaphttp = HttpResponse(template.render({}, request))
        getsitemaphttp['Content-Type'] = 'application/xml'
        return getsitemaphttp


def blog_preview(request,id):
    try:
        current_site = get_current_site(request)
        db = domains.objects.get(domain=current_site)
        get_post = post.objects.get(pk=id, domain=db)
    except:
        return render(request, '404.html')
    else:
        return render(request, 'blog_preview.html', {'title': get_post.title, 'content': get_post.body})


from django import template
from django.contrib.sites.shortcuts import get_current_site
from bigsansar.contrib.blogs.models import post
from bigsansar.contrib.sites.models import domains


register = template.Library()


@register.simple_tag(takes_context=True)
def get_blog(context):
    current_site = get_current_site(context['request'])
    get_pages_filter = post.objects.filter(domain__domain=current_site).order_by('-id')[:10]

    return get_pages_filter


@register.simple_tag(takes_context=True)
def get_blog_object(context):
    get_path_args = context['request'].get_full_path().rsplit('/', 1)[1]
    dd = get_path_args.split('?')[0]
    current_site = get_current_site(context['request'])
    try:
        db = domains.objects.get(domain=current_site)
        get_blog_objects = post.objects.get(domain=db, slug=dd)

    except:
        pass

    else:
        return get_blog_objects